# Generated by Django 4.2.15 on 2024-10-28 02:07

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('artd_order', '0007_orderpaymentmethod'),
    ]

    operations = [
        migrations.AddField(
            model_name='order',
            name='order_payment_method',
            field=models.ForeignKey(blank=True, help_text='Order payment method', null=True, on_delete=django.db.models.deletion.CASCADE, to='artd_order.orderpaymentmethod', verbose_name='Order payment method'),
        ),
    ]
