# Generated by Django 5.0.1 on 2024-03-10 18:47

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_order", "0005_orderadress_json_data_orderstatus_json_data_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="order",
            name="json_data",
            field=models.JSONField(
                blank=True,
                default=dict,
                help_text="JSON data",
                null=True,
                verbose_name="JSON data",
            ),
        ),
        migrations.AlterField(
            model_name="order",
            name="order_status",
            field=models.ForeignKey(
                default=0,
                help_text="Order status",
                on_delete=django.db.models.deletion.CASCADE,
                to="artd_order.orderstatus",
                verbose_name="Order status",
            ),
        ),
        migrations.AlterField(
            model_name="orderadress",
            name="json_data",
            field=models.JSONField(
                blank=True,
                default=dict,
                help_text="JSON data",
                null=True,
                verbose_name="JSON data",
            ),
        ),
        migrations.AlterField(
            model_name="orderdeliverymethod",
            name="json_data",
            field=models.JSONField(
                blank=True,
                default=dict,
                help_text="JSON data",
                null=True,
                verbose_name="JSON data",
            ),
        ),
        migrations.AlterField(
            model_name="orderpaymenthistory",
            name="json_data",
            field=models.JSONField(
                blank=True,
                default=dict,
                help_text="JSON data",
                null=True,
                verbose_name="JSON data",
            ),
        ),
        migrations.AlterField(
            model_name="orderproduct",
            name="json_data",
            field=models.JSONField(
                blank=True,
                default=dict,
                help_text="JSON data",
                null=True,
                verbose_name="JSON data",
            ),
        ),
        migrations.AlterField(
            model_name="orderstatus",
            name="json_data",
            field=models.JSONField(
                blank=True,
                default=dict,
                help_text="JSON data",
                null=True,
                verbose_name="JSON data",
            ),
        ),
        migrations.AlterField(
            model_name="orderstatushistory",
            name="json_data",
            field=models.JSONField(
                blank=True,
                default=dict,
                help_text="JSON data",
                null=True,
                verbose_name="JSON data",
            ),
        ),
    ]
