# Generated by Django 4.2.15 on 2024-10-28 02:05

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('artd_partner', '0007_position_partner'),
        ('artd_order', '0006_alter_order_json_data_alter_order_order_status_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='OrderPaymentMethod',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Date time on which the object was created.', verbose_name='Created at')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Date time on which the object was last updated.', verbose_name='Updated at')),
                ('status', models.BooleanField(default=True, help_text='Status of the object.', verbose_name='Status')),
                ('source', models.CharField(blank=True, help_text='Source of the object.', max_length=100, null=True, verbose_name='Source')),
                ('external_id', models.CharField(blank=True, help_text='External ID of the object.', max_length=100, null=True, verbose_name='External ID')),
                ('json_data', models.JSONField(blank=True, default=dict, help_text='JSON data', null=True, verbose_name='JSON data')),
                ('name', models.CharField(help_text='Name', max_length=100, verbose_name='Name')),
                ('code', models.CharField(help_text='Code', max_length=100, unique=True, verbose_name='Code')),
                ('partner', models.ForeignKey(help_text='Partner', on_delete=django.db.models.deletion.CASCADE, to='artd_partner.partner', verbose_name='Partner')),
            ],
            options={
                'verbose_name': 'Order Payment Method',
                'verbose_name_plural': 'Order Payment Methods',
                'unique_together': {('partner', 'code')},
            },
        ),
    ]
