# Generated by Django 5.0.1 on 2024-03-10 06:10

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_location", "0002_alter_city_created_at_alter_city_status_and_more"),
        ("artd_order", "0002_order_external_id_order_source_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="orderadress",
            name="city",
            field=models.ForeignKey(
                help_text="City",
                on_delete=django.db.models.deletion.CASCADE,
                to="artd_location.city",
                verbose_name="City",
            ),
        ),
    ]
