# Generated by Django 5.0.1 on 2024-03-10 15:06

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_order", "0003_alter_orderadress_city"),
        ("artd_promotion", "0005_alter_promotionrule_categories_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="order",
            name="coupon_code",
            field=models.ForeignKey(
                blank=True,
                help_text="Coupon code",
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="artd_promotion.coupon",
                verbose_name="Coupon code",
            ),
        ),
    ]
