# Generated by Django 5.0.1 on 2024-03-10 15:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_order", "0004_alter_order_coupon_code"),
    ]

    operations = [
        migrations.AddField(
            model_name="orderadress",
            name="json_data",
            field=models.JSONField(
                blank=True, help_text="JSON data", null=True, verbose_name="JSON data"
            ),
        ),
        migrations.AddField(
            model_name="orderstatus",
            name="json_data",
            field=models.JSONField(
                blank=True, help_text="JSON data", null=True, verbose_name="JSON data"
            ),
        ),
        migrations.AddField(
            model_name="orderstatushistory",
            name="json_data",
            field=models.JSONField(
                blank=True, help_text="JSON data", null=True, verbose_name="JSON data"
            ),
        ),
    ]
